@@ -768,15 +768,11 @@ class TibberHome:
         if grid_company and "glitre" in grid_company.lower():
             now = now.astimezone(pytz.timezone("Europe/Oslo"))
             if now.month >= 10 or now.month <= 3:
-                grid_price = 45.99 / 100
+                grid_price = 41.86 / 100
             else:
-                grid_price = 43.74 / 100
-            if (now.month >= 11 or now.month <= 3) and (now.hour >= 22 or now.hour < 6):
+                grid_price = 39.99 / 100
+            if now.hour >= 22 or now.hour < 6:
                 grid_price -= 12 / 100
-            if (now.month >= 4 and now.month <= 10) and (
-                now.hour >= 22 or now.hour < 6
-            ):
-                grid_price -= 2.5 / 100
             attr["grid_price"] = round(grid_price, 3)
 
         return attr
